@@ -1,6 +1,13 @@
 from odoo_somconnexio_python_client.client import Client
 
 
+class Offer:
+    def __init__(self, code, price, name):
+        self.name = name
+        self.code = code
+        self.price = price
+
+
 class Product:
     def __init__(
         self,
@@ -13,6 +20,7 @@ class Product:
         bandwidth="",
         available_for=[],
         has_landline_phone=False,
+        offer=None,
         **kwargs
     ):
         self.code = code
@@ -24,14 +32,31 @@ class Product:
         self.bandwidth = bandwidth
         self.available_for = available_for
         self.has_landline_phone = has_landline_phone
+        if offer is not None:
+            self.offer = Offer(**offer)
+        else:
+            self.offer = None
+
+
+class Pack:
+    def __init__(
+        self, name, code, price, category, products, available_for=[], **kwargs
+    ):
+        self.code = code
+        self.name = name
+        self.price = price
+        self.category = category
+        self.available_for = available_for
+        self.products = [Product(**product) for product in products]
 
 
 class ProductCatalog:
     _url_path = "/product-catalog"
 
-    def __init__(self, code, products, **kwargs):
+    def __init__(self, code, products, packs, **kwargs):
         self.code = code
         self.products = [Product(**product) for product in products]
+        self.packs = [Pack(**pack) for pack in packs]
 
     @classmethod
     def search(cls, code="", category="", lang="ca", product_code=""):
@@ -45,5 +70,4 @@ class ProductCatalog:
         pricelists = []
         for pricelist in response_data.get("pricelists"):
             pricelists.append(cls(**pricelist))
-
         return pricelists
