@@ -4,7 +4,10 @@ import pytest
 import unittest2 as unittest
 
 from odoo_somconnexio_python_client.exceptions import ResourceNotFound
-from odoo_somconnexio_python_client.resources.contract import Contract
+from odoo_somconnexio_python_client.resources.contract import (
+    Contract,
+    FiberContractsToPack,
+)
 
 
 @pytest.fixture(scope="module")
@@ -47,3 +50,25 @@ class ContractTests(unittest.TestCase):
         assert contract.customer_vat == "ES55642302N"
         assert contract.phone_number == "676858494"
         assert contract.current_tariff_product == "SE_SC_REC_MOBILE_T_150_1024"
+
+    @pytest.mark.vcr()
+    def test_search_contract_by_code(self):
+        contracts = Contract.search_by_code(code="78979")
+        contract = contracts[0]
+
+        assert contract.code == "78979"
+        assert contract.customer_vat == "ES55642302N"
+        assert contract.phone_number == "676858494"
+        assert contract.current_tariff_product == "SE_SC_REC_MOBILE_T_150_1024"
+
+
+class FiberContractsToPackTests(unittest.TestCase):
+    @pytest.mark.vcr()
+    def test_search_by_partner_ref(self):
+        contracts = FiberContractsToPack.search_by_partner_ref(partner_ref="1234")
+        contract = contracts[0]
+
+        assert contract.code == "6758"
+        assert contract.customer_vat == "ES55642302N"
+        assert contract.phone_number == "999666888"
+        assert contract.current_tariff_product == "SE_SC_REC_BA_F_100"
