@@ -4,6 +4,7 @@ import pytest
 import unittest2 as unittest
 
 from odoo_somconnexio_python_client.resources.product_catalog import (
+    Offer,
     Product,
     ProductCatalog,
     Pack,
@@ -17,6 +18,7 @@ class TariffTests(unittest.TestCase):
         tariff_names = []
         tariff_codes = []
         tariff_available_for = []
+        tariff_offer = None
 
         pricelist_21IVA = pricelists[0]
         self.assertIsInstance(pricelist_21IVA, ProductCatalog)
@@ -26,11 +28,18 @@ class TariffTests(unittest.TestCase):
             tariff_names.append(product.name)
             tariff_codes.append(product.code)
             tariff_available_for.append(product.available_for)
+            if product.code == "SE_SC_REC_MOBILE_T_UNL_2048":
+                tariff_offer = product.offer
 
         self.assertIn("ADSL sense fix", tariff_names)
         self.assertIn("SE_SC_REC_BA_F_100", tariff_codes)
         self.assertIn(["member"], tariff_available_for)
 
+        self.assertIsInstance(tariff_offer, Offer)
+        self.assertIn("SE_SC_REC_MOBILE_PACK_UNL_2048", tariff_offer.code)
+        self.assertIn("Il·limitades 2 GB associat a fibra", tariff_offer.name)
+        self.assertEqual(8, tariff_offer.price)
+
         adsl_wo_fix_product = list(
             filter(lambda p: p.code == "SE_SC_REC_BA_ADSL_SF", pricelist_21IVA.products)
         )
